package com.google.firebase.crashlytics.buildtools.api;

import com.google.firebase.crashlytics.buildtools.AppBuildInfo;
import com.google.firebase.crashlytics.buildtools.Buildtools;
import com.google.firebase.crashlytics.buildtools.Obfuscator;
import com.google.firebase.crashlytics.buildtools.exception.ZeroByteFileException;
import com.google.firebase.crashlytics.buildtools.utils.FileUtils;
import java.io.BufferedInputStream;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.IOException;
import java.net.URL;
import java.util.zip.GZIPOutputStream;
import org.apache.commons.io.FilenameUtils;
import org.apache.commons.io.IOUtils;
/* loaded from: classes.dex */
public class FirebaseCodeMappingService implements CodeMappingService {
    private static final String GZIPPED_FILE_SUFFIX = ".gz";
    private static final String MAPPING_UPLOAD_REQUEST_FORMAT = "%s/v1/project/-/app/%s/upload/java/%s";
    private static final String SYMBOL_UPLOAD_REQUEST_FORMAT = "%s/v1/project/-/app/%s/upload/native/%s";
    private final WebApi webApi;

    public FirebaseCodeMappingService(WebApi webApi) {
        this.webApi = webApi;
    }

    @Override // com.google.firebase.crashlytics.buildtools.api.CodeMappingService
    public void uploadObfuscatorMappingFile(File file, String str, AppBuildInfo appBuildInfo, Obfuscator obfuscator) throws IOException {
        if (file.length() == 0) {
            throw new ZeroByteFileException(String.format("Mapping file '%s' is zero bytes, skipping upload.", file.getAbsolutePath()));
        }
        File mappingBuildDir = getMappingBuildDir(appBuildInfo.getBuildDir());
        File file2 = new File(mappingBuildDir, str + GZIPPED_FILE_SUFFIX);
        Buildtools.logD("Zipping mapping file: " + file + " -> " + file2);
        gZipFile(file, file2);
        this.webApi.uploadFile(new URL(String.format(MAPPING_UPLOAD_REQUEST_FORMAT, this.webApi.getCodeMappingApiUrl(), appBuildInfo.getGoogleAppId(), str)), file2);
        file2.delete();
    }

    private static File getMappingBuildDir(File file) throws IOException {
        File file2 = new File(file, "mappings");
        FileUtils.verifyDirectory(file2);
        return file2;
    }

    @Override // com.google.firebase.crashlytics.buildtools.api.CodeMappingService
    public void uploadNativeSymbolFile(File file, String str) throws IOException {
        File file2;
        File parentFile = file.getParentFile();
        if (parentFile == null) {
            file2 = new File(FilenameUtils.removeExtension(file.getName()) + GZIPPED_FILE_SUFFIX);
        } else {
            file2 = new File(parentFile, FilenameUtils.removeExtension(file.getName()) + GZIPPED_FILE_SUFFIX);
        }
        gZipFile(file, file2);
        this.webApi.uploadFile(new URL(String.format(SYMBOL_UPLOAD_REQUEST_FORMAT, this.webApi.getCodeMappingApiUrl(), str, getUuid(file))), file2);
        file2.delete();
    }

    private static void gZipFile(File file, File file2) throws IOException {
        BufferedInputStream bufferedInputStream = new BufferedInputStream(new FileInputStream(file));
        try {
            GZIPOutputStream gZIPOutputStream = new GZIPOutputStream(new FileOutputStream(file2));
            IOUtils.copy(bufferedInputStream, gZIPOutputStream);
            gZIPOutputStream.close();
            bufferedInputStream.close();
        } catch (Throwable th) {
            try {
                throw th;
            } catch (Throwable th2) {
                if (th != null) {
                    try {
                        bufferedInputStream.close();
                    } catch (Throwable th3) {
                        th.addSuppressed(th3);
                    }
                } else {
                    bufferedInputStream.close();
                }
                throw th2;
            }
        }
    }

    private static String getUuid(File file) throws IOException {
        String[] split = readCSymHeader(file).split("\t");
        if (split.length != 8 || !split[0].equals("code_mapping")) {
            throw new IOException("Invalid cSYM header for " + file.getAbsolutePath());
        }
        return split[3];
    }

    private static String readCSymHeader(File file) throws IOException {
        BufferedReader bufferedReader = new BufferedReader(new FileReader(file));
        try {
            String readLine = bufferedReader.readLine();
            bufferedReader.close();
            if (readLine == null || readLine.length() == 0) {
                throw new IOException("Could not read cSYM header for " + file.getPath());
            }
            return readLine;
        } catch (Throwable th) {
            try {
                throw th;
            } catch (Throwable th2) {
                if (th != null) {
                    try {
                        bufferedReader.close();
                    } catch (Throwable th3) {
                        th.addSuppressed(th3);
                    }
                } else {
                    bufferedReader.close();
                }
                throw th2;
            }
        }
    }
}
