package org.apache.http.impl.auth;

import java.io.IOException;
import java.util.Locale;
import java.util.Map;
import java.util.Queue;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.http.Header;
import org.apache.http.HttpException;
import org.apache.http.HttpHost;
import org.apache.http.HttpRequest;
import org.apache.http.HttpResponse;
import org.apache.http.auth.AuthOption;
import org.apache.http.auth.AuthProtocolState;
import org.apache.http.auth.AuthScheme;
import org.apache.http.auth.AuthState;
import org.apache.http.auth.AuthenticationException;
import org.apache.http.auth.ContextAwareAuthScheme;
import org.apache.http.auth.Credentials;
import org.apache.http.auth.MalformedChallengeException;
import org.apache.http.client.AuthenticationStrategy;
import org.apache.http.protocol.HttpContext;
import org.apache.http.util.Asserts;
/* loaded from: classes.dex */
public class HttpAuthenticator {
    private final Log log;

    public HttpAuthenticator(Log log) {
        this.log = log == null ? LogFactory.getLog(getClass()) : log;
    }

    public HttpAuthenticator() {
        this(null);
    }

    public boolean isAuthenticationRequested(HttpHost httpHost, HttpResponse httpResponse, AuthenticationStrategy authenticationStrategy, AuthState authState, HttpContext httpContext) {
        if (authenticationStrategy.isAuthenticationRequested(httpHost, httpResponse, httpContext)) {
            this.log.debug("Authentication required");
            if (authState.getState() == AuthProtocolState.SUCCESS) {
                authenticationStrategy.authFailed(httpHost, authState.getAuthScheme(), httpContext);
                return true;
            }
            return true;
        }
        switch (authState.getState()) {
            case CHALLENGED:
            case HANDSHAKE:
                this.log.debug("Authentication succeeded");
                authState.setState(AuthProtocolState.SUCCESS);
                authenticationStrategy.authSucceeded(httpHost, authState.getAuthScheme(), httpContext);
                return false;
            case SUCCESS:
                return false;
            default:
                authState.setState(AuthProtocolState.UNCHALLENGED);
                return false;
        }
    }

    /* JADX WARN: Removed duplicated region for block: B:19:0x0067 A[Catch: MalformedChallengeException -> 0x00dd, TryCatch #0 {MalformedChallengeException -> 0x00dd, blocks: (B:3:0x0001, B:5:0x0009, B:6:0x0023, B:8:0x002d, B:10:0x0035, B:11:0x0046, B:28:0x00a9, B:30:0x00af, B:32:0x00b5, B:34:0x00bd, B:35:0x00d3, B:14:0x004b, B:16:0x0051, B:19:0x0067, B:21:0x0079, B:23:0x0089, B:25:0x00a0, B:27:0x00a6), top: B:44:0x0001 }] */
    /* JADX WARN: Removed duplicated region for block: B:30:0x00af A[Catch: MalformedChallengeException -> 0x00dd, TryCatch #0 {MalformedChallengeException -> 0x00dd, blocks: (B:3:0x0001, B:5:0x0009, B:6:0x0023, B:8:0x002d, B:10:0x0035, B:11:0x0046, B:28:0x00a9, B:30:0x00af, B:32:0x00b5, B:34:0x00bd, B:35:0x00d3, B:14:0x004b, B:16:0x0051, B:19:0x0067, B:21:0x0079, B:23:0x0089, B:25:0x00a0, B:27:0x00a6), top: B:44:0x0001 }] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public boolean handleAuthChallenge(HttpHost httpHost, HttpResponse httpResponse, AuthenticationStrategy authenticationStrategy, AuthState authState, HttpContext httpContext) {
        Queue<AuthOption> select;
        try {
            if (this.log.isDebugEnabled()) {
                Log log = this.log;
                log.debug(httpHost.toHostString() + " requested authentication");
            }
            Map<String, Header> challenges = authenticationStrategy.getChallenges(httpHost, httpResponse, httpContext);
            if (challenges.isEmpty()) {
                this.log.debug("Response contains no authentication challenges");
                return false;
            }
            AuthScheme authScheme = authState.getAuthScheme();
            switch (authState.getState()) {
                case CHALLENGED:
                case HANDSHAKE:
                    if (authScheme == null) {
                        this.log.debug("Auth scheme is null");
                        authenticationStrategy.authFailed(httpHost, null, httpContext);
                        authState.reset();
                        authState.setState(AuthProtocolState.FAILURE);
                        return false;
                    }
                    if (authScheme != null) {
                        Header header = challenges.get(authScheme.getSchemeName().toLowerCase(Locale.ROOT));
                        if (header != null) {
                            this.log.debug("Authorization challenge processed");
                            authScheme.processChallenge(header);
                            if (authScheme.isComplete()) {
                                this.log.debug("Authentication failed");
                                authenticationStrategy.authFailed(httpHost, authState.getAuthScheme(), httpContext);
                                authState.reset();
                                authState.setState(AuthProtocolState.FAILURE);
                                return false;
                            }
                            authState.setState(AuthProtocolState.HANDSHAKE);
                            return true;
                        }
                        authState.reset();
                    }
                    select = authenticationStrategy.select(challenges, httpHost, httpResponse, httpContext);
                    if (select != null || select.isEmpty()) {
                        return false;
                    }
                    if (this.log.isDebugEnabled()) {
                        Log log2 = this.log;
                        log2.debug("Selected authentication options: " + select);
                    }
                    authState.setState(AuthProtocolState.CHALLENGED);
                    authState.update(select);
                    return true;
                case SUCCESS:
                    authState.reset();
                    select = authenticationStrategy.select(challenges, httpHost, httpResponse, httpContext);
                    if (select != null) {
                        break;
                    }
                    return false;
                case FAILURE:
                    return false;
                case UNCHALLENGED:
                    if (authScheme != null) {
                    }
                    select = authenticationStrategy.select(challenges, httpHost, httpResponse, httpContext);
                    if (select != null) {
                    }
                    return false;
                default:
                    select = authenticationStrategy.select(challenges, httpHost, httpResponse, httpContext);
                    if (select != null) {
                    }
                    return false;
            }
        } catch (MalformedChallengeException e) {
            if (this.log.isWarnEnabled()) {
                Log log3 = this.log;
                log3.warn("Malformed challenge: " + e.getMessage());
            }
            authState.reset();
            return false;
        }
    }

    public void generateAuthResponse(HttpRequest httpRequest, AuthState authState, HttpContext httpContext) throws HttpException, IOException {
        AuthScheme authScheme = authState.getAuthScheme();
        Credentials credentials = authState.getCredentials();
        int i = AnonymousClass1.$SwitchMap$org$apache$http$auth$AuthProtocolState[authState.getState().ordinal()];
        if (i != 1) {
            switch (i) {
                case 4:
                    return;
                case 3:
                    ensureAuthScheme(authScheme);
                    if (authScheme.isConnectionBased()) {
                        return;
                    }
                    break;
            }
        } else {
            Queue<AuthOption> authOptions = authState.getAuthOptions();
            if (authOptions != null) {
                while (!authOptions.isEmpty()) {
                    AuthOption remove = authOptions.remove();
                    AuthScheme authScheme2 = remove.getAuthScheme();
                    Credentials credentials2 = remove.getCredentials();
                    authState.update(authScheme2, credentials2);
                    if (this.log.isDebugEnabled()) {
                        Log log = this.log;
                        log.debug("Generating response to an authentication challenge using " + authScheme2.getSchemeName() + " scheme");
                    }
                    try {
                        httpRequest.addHeader(doAuth(authScheme2, credentials2, httpRequest, httpContext));
                        return;
                    } catch (AuthenticationException e) {
                        if (this.log.isWarnEnabled()) {
                            Log log2 = this.log;
                            log2.warn(authScheme2 + " authentication error: " + e.getMessage());
                        }
                    }
                }
                return;
            }
            ensureAuthScheme(authScheme);
        }
        if (authScheme != null) {
            try {
                httpRequest.addHeader(doAuth(authScheme, credentials, httpRequest, httpContext));
            } catch (AuthenticationException e2) {
                if (this.log.isErrorEnabled()) {
                    Log log3 = this.log;
                    log3.error(authScheme + " authentication error: " + e2.getMessage());
                }
            }
        }
    }

    private void ensureAuthScheme(AuthScheme authScheme) {
        Asserts.notNull(authScheme, "Auth scheme");
    }

    private Header doAuth(AuthScheme authScheme, Credentials credentials, HttpRequest httpRequest, HttpContext httpContext) throws AuthenticationException {
        if (authScheme instanceof ContextAwareAuthScheme) {
            return ((ContextAwareAuthScheme) authScheme).authenticate(credentials, httpRequest, httpContext);
        }
        return authScheme.authenticate(credentials, httpRequest);
    }
}
